@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2012-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-keybinding.h>
@@ -30,7 +17,7 @@ typedef struct _GPasteKeybindingPrivate
     guint32               *keycodes;
 } GPasteKeybindingPrivate;
 
-G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GPasteKeybinding, g_paste_keybinding, G_TYPE_OBJECT)
+G_PASTE_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (Keybinding, keybinding, G_TYPE_OBJECT)
 
 /**
  * g_paste_keybinding_get_modifiers:
@@ -43,9 +30,9 @@ G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GPasteKeybinding, g_paste_keybinding, G_TYP
 G_PASTE_VISIBLE GdkModifierType
 g_paste_keybinding_get_modifiers (const GPasteKeybinding *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_KEYBINDING (self), 0);
+    g_return_val_if_fail (_G_PASTE_IS_KEYBINDING (self), 0);
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     return priv->modifiers;
 }
@@ -61,9 +48,9 @@ g_paste_keybinding_get_modifiers (const GPasteKeybinding *self)
 G_PASTE_VISIBLE const guint32 *
 g_paste_keybinding_get_keycodes (const GPasteKeybinding *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_KEYBINDING (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_KEYBINDING (self), NULL);
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     return priv->keycodes;
 }
@@ -79,9 +66,9 @@ g_paste_keybinding_get_keycodes (const GPasteKeybinding *self)
 G_PASTE_VISIBLE const gchar *
 g_paste_keybinding_get_dconf_key (const GPasteKeybinding *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_KEYBINDING ((gpointer) self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_KEYBINDING ((gpointer) self), NULL);
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     return priv->dconf_key;
 }
@@ -98,10 +85,10 @@ G_PASTE_VISIBLE const gchar *
 g_paste_keybinding_get_accelerator (const GPasteKeybinding *self,
                                     const GPasteSettings   *settings)
 {
-    g_return_val_if_fail (G_PASTE_IS_KEYBINDING ((gpointer) self), NULL);
-    g_return_val_if_fail (G_PASTE_IS_SETTINGS ((gpointer) settings), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_KEYBINDING ((gpointer) self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_SETTINGS ((gpointer) settings), NULL);
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     return priv->getter (settings);
 }
@@ -112,15 +99,13 @@ g_paste_keybinding_get_accelerator (const GPasteKeybinding *self,
  * @settings: a #GPasteSettings instance
  *
  * Activate the keybinding
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_keybinding_activate (GPasteKeybinding *self,
                              GPasteSettings   *settings)
 {
-    g_return_if_fail (G_PASTE_IS_KEYBINDING (self));
-    g_return_if_fail (G_PASTE_IS_SETTINGS (settings));
+    g_return_if_fail (_G_PASTE_IS_KEYBINDING (self));
+    g_return_if_fail (_G_PASTE_IS_SETTINGS (settings));
 
     GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
 
@@ -141,13 +126,11 @@ g_paste_keybinding_activate (GPasteKeybinding *self,
  * @self: a #GPasteKeybinding instance
  *
  * Deactivate the keybinding
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_keybinding_deactivate (GPasteKeybinding *self)
 {
-    g_return_if_fail (G_PASTE_IS_KEYBINDING (self));
+    g_return_if_fail (_G_PASTE_IS_KEYBINDING (self));
 
     GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
 
@@ -167,17 +150,17 @@ g_paste_keybinding_deactivate (GPasteKeybinding *self)
 G_PASTE_VISIBLE gboolean
 g_paste_keybinding_is_active (GPasteKeybinding *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_KEYBINDING (self), FALSE);
+    g_return_val_if_fail (_G_PASTE_IS_KEYBINDING (self), FALSE);
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     return priv->active;
 }
 
 static gboolean
-g_paste_keybinding_private_match (GPasteKeybindingPrivate *priv,
-                                  GdkModifierType          modifiers,
-                                  guint64                  keycode)
+g_paste_keybinding_private_match (const GPasteKeybindingPrivate *priv,
+                                  GdkModifierType                modifiers,
+                                  guint64                        keycode)
 {
     if (priv->keycodes && priv->modifiers == (priv->modifiers & modifiers))
     {
@@ -198,17 +181,15 @@ g_paste_keybinding_private_match (GPasteKeybindingPrivate *priv,
  * @keycode: the keycode of the current event
  *
  * Runs the callback associated to the keybinding if needed
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_keybinding_notify (GPasteKeybinding *self,
                            GdkModifierType   modifiers,
                            guint64           keycode)
 {
-    g_return_if_fail (G_PASTE_IS_KEYBINDING (self));
+    g_return_if_fail (_G_PASTE_IS_KEYBINDING (self));
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     if (keycode && g_paste_keybinding_private_match (priv, modifiers, keycode))
         priv->callback (self, priv->user_data);
@@ -219,15 +200,13 @@ g_paste_keybinding_notify (GPasteKeybinding *self,
  * @self: a #GPasteKeybinding instance
  *
  * Runs the callback associated to the keybinding
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_keybinding_perform (GPasteKeybinding *self)
 {
-    g_return_if_fail (G_PASTE_IS_KEYBINDING (self));
+    g_return_if_fail (_G_PASTE_IS_KEYBINDING (self));
 
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     priv->callback (self, priv->user_data);
 }
@@ -236,7 +215,7 @@ static void
 g_paste_keybinding_dispose (GObject *object)
 {
     GPasteKeybinding *self = G_PASTE_KEYBINDING (object);
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (self);
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (self);
 
     if (priv->active)
         g_paste_keybinding_deactivate (self);
@@ -247,7 +226,7 @@ g_paste_keybinding_dispose (GObject *object)
 static void
 g_paste_keybinding_finalize (GObject *object)
 {
-    GPasteKeybindingPrivate *priv = g_paste_keybinding_get_instance_private (G_PASTE_KEYBINDING (object));
+    const GPasteKeybindingPrivate *priv = _g_paste_keybinding_get_instance_private (G_PASTE_KEYBINDING (object));
 
     g_free (priv->keycodes);
     g_free (priv->dconf_key);
